<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQT-ის თაგუნას თემის მორგება</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>აირჩიეთ კურსორის თემა, რომლის გამოყენებაც გნებავთ (სანახავად ზედ კურსორი გადაატარეთ). &lt;b&gt;ამ ცვლილების შემდეგ LXQT-ის სესიას გადატვირთვა სჭირდება&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="104"/>
        <source>&amp;Install New Theme...</source>
        <translation>ახალ&amp;ი თემის დაყენება....</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>ამ ცვლილების შემდეგ LXQT-ის სესიას გადატვირთვა სჭირდება.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>&amp;Remove Theme</source>
        <translation>თემის &amp;წაშლა</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="65"/>
        <source>Size:</source>
        <translation>ზომა:</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="231"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme-ის შეცდომა</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="232"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>აქტიურ თემას ვერ წაშლით!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>ფორმა</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt-მა კურსორის თემა ვერ იპოვა. გამოყენებული იქნება ნაგულისხმევი X11-ის კურსორის თემა. LXQt-მა ეძება შემდეგ საქაღალდეებში:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>ჩვენება...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Name</source>
        <translation>სახელი</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="63"/>
        <source>Description</source>
        <translation>აღწერა</translation>
    </message>
</context>
</TS>
